@@ -60,6 +60,29 @@ class TestMRUplift(object):
 
         assert uplift_model.get_erupt_curves(x = x, y = y, t = t)
 
+    def test_model_pred_oos_shapes_single_col_tmt(self):
+        num_obs = 1000
+
+        y, x, t = get_simple_uplift_data(num_obs)
+
+        t = t.reshape(-1, 1)
+
+        param_grid = dict(num_nodes=[8], dropout=[.1], activation=[
+                                  'relu'], num_layers=[1], epochs=[1], batch_size=[1000])
+
+        uplift_model = MRUplift()
+        uplift_model.fit(x, y, t, param_grid = param_grid, n_jobs=1)
+
+        assert uplift_model.predict_ice().shape == (
+            np.unique(t, axis=0).shape[0], num_obs * .7, y.shape[1])
+
+        assert uplift_model.predict_ice(x=x).shape == (np.unique(t,axis=0).shape[0],
+            num_obs,
+            y.shape[1])
+
+        assert uplift_model.get_erupt_curves()
+
+        assert uplift_model.get_erupt_curves(x = x, y = y, t = t)
 
     def test_prepare_data_optimized_loss_one_col_tmt(self):
         num_obs = 1000
